# QuantumFluidSpectra.jl

<!-- [![Stable](https://img.shields.io/badge/docs-stable-blue.svg)](https://AshtonSBradley.github.io/QuantumFluidSpectra.jl/stable)
[![Dev](https://img.shields.io/badge/docs-dev-blue.svg)](https://AshtonSBradley.github.io/QuantumFluidSpectra.jl/dev) -->
[![Build Status](https://github.com/AshtonSBradley/QuantumFluidSpectra.jl/workflows/CI/badge.svg)](https://github.com/AshtonSBradley/QuantumFluidSpectra.jl/actions)
[![Coverage](https://codecov.io/gh/AshtonSBradley/QuantumFluidSpectra.jl/branch/master/graph/badge.svg)](https://codecov.io/gh/AshtonSBradley/QuantumFluidSpectra.jl)

This package provides methods to calculate energy spectra of compressible quantum fluids described by a wavefunction, including dilute-gas Bose-Einstein condensates, polariton BEC, and quantum fluids of light. 


Fast, accurate, and flexible spectral analysis provides a wealth of information about nonlinear quantum fluid dynamics. 

We rely on Fourier spectral methods throughout. The user provides a wavefunction and minimal information about the spatial domain. 

<details><summary><b>Create Field</b></summary>

```julia
# Create arrays including `x` and `k` grids

    n = 100
    L = (1,1)
    N = (n,n)
    X,K,dX,dK = makearrays(L,N) # setup domain
```
```julia
# make a test field
    ktest = K[1][2] # pick one of the `k` values
    ψ = @. exp(im*ktest*X[1]*one.(X[2]'))
    psi = Psi(ψ,X,K) # make field object with required arrays.
```
</details>
<details><summary><b>Basic Usage</b></summary>

```julia 
k = LinRange(0.05,10,300) # can be anything
εki = incompressible_spectrum(k,psi)
r = LinRange(0,10,300) # can be anything
gi = gv(r,k,εki) # pass k vals on which εki is defined
```
</details>

# Citation
If you use `QuantumFluidSpectra.jl` please cite the paper

```bib
@article{bradley_spectral_2021,
  title = {Spectral Analysis for Compressible Quantum Fluids},
  author = {Bradley, Ashton S. and Kumar, R. Kishor and Pal, Sukla and Yu, Xiaoquan},
  year = {2021},
  journal = {arXiv preprint arXiv:2112.04012}
}
```